@@ -40,6 +40,7 @@ import com.google.zxing.oned.rss.FinderPattern;
 import com.google.zxing.oned.rss.RSSUtils;
 import com.google.zxing.oned.rss.expanded.decoders.AbstractExpandedDecoder;
 
+import java.util.Arrays;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
@@ -165,7 +166,7 @@ public final class RSSExpandedReader extends AbstractRSSReader {
     }
 
     boolean tryStackedDecode = !this.rows.isEmpty();
-    storeRow(rowNumber, false); // TODO: deal with reversed rows
+    storeRow(rowNumber); // TODO: deal with reversed rows
     if (tryStackedDecode) {
       // When the image is 180-rotated, then rows are sorted in wrong direction.
       // Try twice with both the directions.
@@ -262,7 +263,7 @@ public final class RSSExpandedReader extends AbstractRSSReader {
     return false;
   }
 
-  private void storeRow(int rowNumber, boolean wasReversed) {
+  private void storeRow(int rowNumber) {
     // Discard if duplicate above or below; otherwise insert in order by row number.
     int insertPos = 0;
     boolean prevIsSame = false;
@@ -289,7 +290,7 @@ public final class RSSExpandedReader extends AbstractRSSReader {
       return;
     }
 
-    this.rows.add(insertPos, new ExpandedRow(this.pairs, rowNumber, wasReversed));
+    this.rows.add(insertPos, new ExpandedRow(this.pairs, rowNumber, false));
 
     removePartialRows(this.pairs, this.rows);
   }
@@ -571,9 +572,7 @@ public final class RSSExpandedReader extends AbstractRSSReader {
                                     boolean isOddPattern,
                                     boolean leftChar) throws NotFoundException {
     int[] counters = this.getDataCharacterCounters();
-    for (int x = 0; x < counters.length; x++) {
-      counters[x] = 0;
-    }
+    Arrays.fill(counters, 0);
 
     if (leftChar) {
       recordPatternInReverse(row, pattern.getStartEnd()[0], counters);
