@@ -23,9 +23,10 @@ import javax.servlet.annotation.WebInitParam;
  * Protect the /chart endpoint from too many requests.
  */
 @WebFilter(urlPatterns = {"/w/chart"}, initParams = {
-  @WebInitParam(name = "maxAccessPerTime", value = "250"),
-  @WebInitParam(name = "accessTimeSec", value = "500"),
-  @WebInitParam(name = "maxEntries", value = "10000")
+  @WebInitParam(name = "maxAccessPerTime", value = "120"),
+  @WebInitParam(name = "accessTimeSec", value = "60"),
+  @WebInitParam(name = "maxEntries", value = "10000"),
+  @WebInitParam(name = "maxLoad", value = "0.9")
 })
 public final class ChartDoSFilter extends DoSFilter {
   // no additional implementation
